### R code from vignette source 'simFrame-eusilc.Rnw'

###################################################
### code chunk number 1: simFrame-eusilc.Rnw:70-71
###################################################
options(width=72, prompt="R> ")


###################################################
### code chunk number 2: simFrame-eusilc.Rnw:130-133
###################################################
library("simFrame")
library("laeken")
data("eusilcP")


###################################################
### code chunk number 3: simFrame-eusilc.Rnw:140-152
###################################################
## define function for simulation runs
sim <- function(x, k) {
    x <- x[!is.na(x$eqIncome), ]
    g <- gini(x$eqIncome, x$.weight)$value
    eqIncHill <- fitPareto(x$eqIncome, k = k, 
        method = "thetaHill", groups = x$hid)
    gHill <- gini(eqIncHill, x$.weight)$value
    eqIncPDC <- fitPareto(x$eqIncome, k = k, 
        method = "thetaPDC", groups = x$hid)
    gPDC <- gini(eqIncPDC, x$.weight)$value
    c(standard = g, Hill = gHill, PDC = gPDC)
}


###################################################
### code chunk number 4: simFrame-eusilc.Rnw:167-173
###################################################
set.seed(12345)
## set up samples
sc <- SampleControl(grouping = "hid", size = 1500, k = 100)
#sc <- SampleControl(grouping = "hid", size = 1500, k = 6)
## run simulation
results <- runSimulation(eusilcP, sc, fun = sim, k = 175)


###################################################
### code chunk number 5: simFrame-eusilc.Rnw:182-190
###################################################
## show the first results
head(results)
## aggregate results
aggregate(results)
## compute true values
tv <- gini(eusilcP$eqIncome)$value
## plot results
plot(results, true = tv)


###################################################
### code chunk number 6: simFrame-eusilc.Rnw:205-206
###################################################
print(plot(results, true = tv))


###################################################
### code chunk number 7: simFrame-eusilc.Rnw:221-228
###################################################
set.seed(12345)
## set up samples
sc <- SampleControl(design = "region", grouping = "hid", 
    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 100)
#    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 6)
## run simulation
results <- runSimulation(eusilcP, sc, fun = sim, k = 175)


###################################################
### code chunk number 8: simFrame-eusilc.Rnw:232-240
###################################################
## show the first results
head(results)
## aggregate results
aggregate(results)
## compute true values
tv <- gini(eusilcP$eqIncome)$value
## plot results
plot(results, true = tv)


###################################################
### code chunk number 9: simFrame-eusilc.Rnw:246-247
###################################################
print(plot(results, true = tv))


###################################################
### code chunk number 10: simFrame-eusilc.Rnw:273-284
###################################################
set.seed(12345)
## set up samples
sc <- SampleControl(design = "region", grouping = "hid", 
    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 100)
#    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 6)
## define contamination
cc <- DCARContControl(target = "eqIncome", epsilon = 0.005, 
    grouping = "hid", dots = list(mean = 500000, sd = 10000))
## run simulation
results <- runSimulation(eusilcP, sc, 
    contControl = cc, fun = sim, k = 175)


###################################################
### code chunk number 11: simFrame-eusilc.Rnw:289-297
###################################################
## show the first results
head(results)
## aggregate results
aggregate(results)
## compute true values
tv <- gini(eusilcP$eqIncome)$value
## plot results
plot(results, true = tv)


###################################################
### code chunk number 12: simFrame-eusilc.Rnw:303-304
###################################################
print(plot(results, true = tv))


###################################################
### code chunk number 13: simFrame-eusilc.Rnw:341-352
###################################################
set.seed(12345)
## set up samples
sc <- SampleControl(design = "region", grouping = "hid", 
    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 100)
#    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 6)
## define contamination
cc <- DCARContControl(target = "eqIncome", epsilon = 0.005, 
    grouping = "hid", dots = list(mean = 500000, sd = 10000))
## run simulation
results <- runSimulation(eusilcP, sc, contControl = cc, 
    design = "gender", fun = sim, k = 125)


###################################################
### code chunk number 14: simFrame-eusilc.Rnw:361-369
###################################################
## show the first results
head(results)
## aggregate results
aggregate(results)
## compute true values
tv <- simSapply(eusilcP, "gender", function(x) gini(x$eqIncome)$value)
## plot results
plot(results, true = tv)


###################################################
### code chunk number 15: simFrame-eusilc.Rnw:375-376
###################################################
print(plot(results, true = tv))


###################################################
### code chunk number 16: simFrame-eusilc.Rnw:399-411
###################################################
set.seed(12345)
## set up samples
sc <- SampleControl(design = "region", grouping = "hid", 
    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 100)
#    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 6)
## define contamination
cc <- DCARContControl(target = "eqIncome", 
    epsilon = c(0, 0.0025, 0.005, 0.0075, 0.01),
    dots = list(mean = 500000, sd = 10000))
## run simulation
results <- runSimulation(eusilcP, sc, contControl = cc, 
    design = "gender", fun = sim, k = 125)


###################################################
### code chunk number 17: simFrame-eusilc.Rnw:416-424
###################################################
## show the first results
head(results)
## aggregate results
aggregate(results)
## compute true values
tv <- simSapply(eusilcP, "gender", function(x) gini(x$eqIncome)$value)
## plot results
plot(results, true = tv)


###################################################
### code chunk number 18: simFrame-eusilc.Rnw:430-431
###################################################
print(plot(results, true = tv))


###################################################
### code chunk number 19: simFrame-eusilc.Rnw:479-494
###################################################
set.seed(12345)
## set up samples
sc <- SampleControl(design = "region", grouping = "hid", 
    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 50)
#    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 6)
## define contamination
cc <- DCARContControl(target = "eqIncome", 
    epsilon = c(0, 0.005, 0.01), dots = list(mean = 500000, sd = 10000))
## define missing values
#nc <- NAControl(target = "eqIncome", 
#    NArate = c(0, 0.05), aux = "eqIncome")
nc <- NAControl(target = "eqIncome", NArate = c(0, 0.05))
## run simulation
results <- runSimulation(eusilcP, sc, contControl = cc, 
    NAControl = nc, design = "gender", fun = sim, k = 125)


###################################################
### code chunk number 20: simFrame-eusilc.Rnw:501-509
###################################################
## show the first results
head(results)
## aggregate results
aggregate(results)
## compute true values
tv <- simSapply(eusilcP, "gender", function(x) gini(x$eqIncome)$value)
## plot results
plot(results, true = tv)


###################################################
### code chunk number 21: simFrame-eusilc.Rnw:516-517
###################################################
print(plot(results, true = tv))


###################################################
### code chunk number 22: simFrame-eusilc.Rnw:548-577
###################################################
## start snow cluster
cl <- makeCluster(4, type="SOCK")
## load required packages on workers
clusterEvalQ(cl, {
        library("simFrame")
        library("laeken")
        data("eusilcP")
    })
## setup random number stream
clusterSetupRNG(cl, seed=12345)
## define samples
sc <- SampleControl(design = "region", grouping = "hid", 
    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 50)
#    size = c(75, 250, 250, 125, 200, 225, 125, 150, 100), k = 6)
## define contamination
cc <- DCARContControl(target = "eqIncome", 
    epsilon = c(0, 0.005, 0.01), dots = list(mean = 500000, sd = 10000))
## define missing values
#nc <- NAControl(target = "eqIncome", 
#    NArate = c(0, 0.05), aux = "eqIncome")
nc <- NAControl(target = "eqIncome", NArate = c(0, 0.05))
## export object to workers
clusterExport(cl, c("sc", "cc", "nc", "sim"))
## run simulation
results <- clusterRunSimulation(cl, eusilcP, sc, 
    contControl = cc, NAControl = nc, design = "gender", 
    fun = sim, k = 125)
## stop snow cluster
stopCluster(cl)


###################################################
### code chunk number 23: simFrame-eusilc.Rnw:581-589
###################################################
## show the first results
head(results)
## aggregate results
aggregate(results)
## compute true values
tv <- simSapply(eusilcP, "gender", function(x) gini(x$eqIncome)$value)
## plot results
plot(results, true = tv)


###################################################
### code chunk number 24: simFrame-eusilc.Rnw:596-597
###################################################
print(plot(results, true = tv))


